@@ -18,32 +18,72 @@ define([
      */
     var _VP_SHOW_RESULT = true;
 
+    const _VP_BOOL_OPTIONS = [
+        { label: 'Select option...', value: ''},
+        { label: 'True', value: 'True' },
+        { label: 'False', value: 'False' }
+    ]
+
      /**
      * Generate page interface based on package configuration
      * @param {*} package 
      */
     var vp_showInterfaceOnPage = function(selector, package) {
 
+        let autoCols = {};
+
         // generate input variable tag
-        var tblInput = $(selector+' #vp_inputOutputBox table');
+        var tblInput = $(selector+' #vp_inputOutputBox table tbody');
         package.input && package.input.forEach(function(o, i) {
             var obj = JSON.parse(JSON.stringify(o));
             tblInput.append(vp_createTag(selector, obj, true, (obj.required == false? false: true)));
+            if (obj.component === 'col_select') {
+                if (autoCols[obj.target] != undefined) {
+                    autoCols[obj.target].push(obj.name);
+                } else {
+                    autoCols[obj.target] = [ obj.name ];
+                }
+            }
         });
 
         // generate option variable tag
-        var tblOption = $(selector+' #vp_optionBox table');
+        var tblOption = $(selector+' #vp_optionBox table tbody');
         package.variable && package.variable.forEach(function(o, i) {
             // cell metadata test
             var obj = JSON.parse(JSON.stringify(o)); // deep copy
             tblOption.append(vp_createTag(selector, obj, true, (obj.required == true)));
+            if (obj.component === 'col_select') {
+                if (autoCols[obj.target] != undefined) {
+                    autoCols[obj.target].push(obj.name);
+                } else {
+                    autoCols[obj.target] = [ obj.name ];
+                }
+            }
         });
 
         // generate output variable tag
-        var tblOutput = $(selector+' #vp_inputOutputBox table');
+        var tblOutput = $(selector+' #vp_inputOutputBox table tbody');
         package.output && package.output.forEach(function(o, i) {
             var obj = JSON.parse(JSON.stringify(o)); // deep copy
             tblOutput.append(vp_createTag(selector, obj, true, (obj.required == true)));
+            if (obj.component === 'col_select') {
+                if (autoCols[obj.target] != undefined) {
+                    autoCols[obj.target].push(obj.name);
+                } else {
+                    autoCols[obj.target] = [ obj.name ];
+                }
+            }
+        });
+
+        // bind column list FIXME: change event not triggered on changing df input
+        Object.keys(autoCols).forEach(target => {
+            let targetSelector = selector + ' #' + target;
+            vp_bindColumnSource(selector, targetSelector, autoCols[target]);
+            // on change event
+            $(targetSelector).on('change', function() {
+                // console.log('change event ', selector, targetSelector, autoCols[target]);
+                vp_bindColumnSource(selector, this, autoCols[target]);
+            });
         });
     }
 
@@ -73,11 +113,34 @@ define([
         // create as component type
         switch (obj.component) {
             case 'bool_checkbox':
-                // FIXME: True False select box
-                var select = $(`<select id="${obj.name}" class="vp-select vp-state"><option value="">Default</option></select>`);
-                select.append($('<option value="True">True</option>'))
-                    .append($('<option value="False">False</option>'));
-                $(tblInput).append(select);
+                // True False select box
+                var optSlct = $(`<select id="${obj.name}" class="vp-select vp-state"></select>`);
+                _VP_BOOL_OPTIONS.forEach((opt, idx) => {
+                    var option = $(`<option>${opt.label}${obj.default==opt.value?' (default)':''}</option>`).attr({
+                        // 'id':opt,
+                        'index':obj.index,
+                        'name':obj.name,
+                        // 'value':(obj.default==opt.value?'':opt.value)
+                        'value':opt.value
+
+                    });
+                    // cell metadata test
+                    if (getValue && obj.value != undefined) {
+                        // set as saved value
+                        if (obj.value == opt) {
+                            $(option).attr({
+                                'selected':'selected'
+                            });
+                        }
+                    } else if (obj.default == opt.value) {
+                        // set default value
+                        // $(option).attr({
+                        //     'selected':'selected'
+                        // });
+                    }
+                    optSlct.append(option);
+                });
+                $(tblInput).append(optSlct);
                 break;
             case 'option_select':
                 var optSlct = document.createElement('select');
@@ -87,7 +150,7 @@ define([
                 });
                 // if required, no default option
                 if (required != true) {
-                    $(optSlct).append($('<option value="">Default</option>'));
+                    $(optSlct).append($('<option value="">Select option...</option>'));
                 }
                 obj.options.forEach((opt, idx, arr) => {
                     var label = (obj.options_label != undefined? obj.options_label[idx]:opt);
@@ -112,15 +175,40 @@ define([
                 });
                 tblInput.appendChild(optSlct);
                 break;
+            case 'option_suggest':
+                    // suggest input tag
+                    // 1. Target Variable
+                    var suggestInput = new SuggestInput();
+                    suggestInput.setComponentID(obj.name);
+                    suggestInput.addClass('vp-input vp-state');
+                    suggestInput.setSuggestList(function() { return obj.options; });
+                    suggestInput.setNormalFilter(obj.useFilter == undefined?false:obj.useFilter);
+                    suggestInput.setValue(obj.value);
+                    if (obj.placeholder != undefined) {
+                        suggestInput.setPlaceholder(obj.placeholder);
+                    } else {
+                        suggestInput.setPlaceholder('Type or Select value');
+                    }
+                    if (required === true) {
+                        suggestInput.addAttribute('required', true);
+                    }
+                    suggestInput.setSelectEvent(function(selectedValue) {
+                        // trigger change
+                        $(pageThis.wrapSelector('#' + obj.name)).val(selectedValue);
+                        $(pageThis.wrapSelector('#' + obj.name)).trigger('change');
+                    });
+                    tblInput.appendChild($(suggestInput.toTagString())[0]);
+                    break;
             case 'var_select':
                 // suggest input tag
                 var tag = document.createElement('input');
                 $(tag).attr({
                     'type': 'text',
                     'id': obj.name,
-                    'class': 'vp-input vp-state'
+                    'class': 'vp-input vp-state',
+                    'required': required === true
                 });
-                vp_generateVarSuggestInput(divTag, obj);
+                vp_generateVarSuggestInput(divTag, obj, required);
                 tblInput.appendChild(tag);
                 break;
             case 'var_multi':
@@ -135,6 +223,15 @@ define([
                 vp_generateVarSelect(tag, obj.var_type, obj.value);
                 tblInput.appendChild(tag);
                 break;
+            case 'col_select':
+                var tag = document.createElement('input');
+                $(tag).attr({
+                    'type': 'text',
+                    'id': obj.name,
+                    'class': 'vp-input vp-state'
+                });
+                tblInput.appendChild(tag);
+                break;
             case 'textarea':
                 var textarea = $(`<textarea id="${obj.name}" class="vp-textarea vp-state">${(obj.default==undefined?'':obj.default)}</textarea>`);
                 // cell metadata test
@@ -144,11 +241,30 @@ define([
                 }
                 $(tblInput).append(textarea);
                 break;
+            case 'input_number':
+                var input = com_makeDom.renderInput({
+                    'type': 'number',
+                    'class': 'vp-input vp-state',
+                    'id': obj.name,
+                    'placeholder': (obj.placeholder==undefined?'':obj.placeholder),
+                    'value': (obj.default==undefined?'':obj.default),
+                    'title': (obj.help==undefined?'':obj.help),
+                    'required': required === true
+                });
+                // cell metadata test
+                if (getValue && obj.value != undefined) {
+                    // set as saved value
+                    input.attr({
+                        'value': obj.value
+                    });
+                }
+                $(tblInput).append(input);
+                break;
             case 'table':
                 // break;
             case 'file':
                 // break;
-            // default : input_single
+                // default : input_single
             default:
                 // FIXME: use makedom
                 var input = com_makeDom.renderInput({
@@ -157,7 +273,8 @@ define([
                     'id':obj.name,
                     'placeholder':(obj.placeholder==undefined?'':obj.placeholder),
                     'value':(obj.default==undefined?'':obj.default),
-                    'title':(obj.help==undefined?'':obj.help)
+                    'title':(obj.help==undefined?'':obj.help),
+                    'required': required === true
                 });
                 // cell metadata test
                 if (getValue && obj.value != undefined) {
@@ -178,7 +295,7 @@ define([
      * Generate suggest input
      * @param {object} obj
      */
-    var vp_generateVarSuggestInput = function(divTag, obj) {
+    var vp_generateVarSuggestInput = function(divTag, obj, required=false) {
         var types = obj.var_type;
         var defaultValue = obj.value;
 
@@ -197,7 +314,7 @@ define([
             let { result, type, msg } = resultObj;
             var varList = JSON.parse(result);
             varList = varList.map(function(v) {
-                return { label: v.varName + ' (' + v.varType + ')', value: v.varName, dtype: v.varType };
+                return { label: v.varName, value: v.varName, dtype: v.varType };
             });
             // 1. Target Variable
             var suggestInput = new SuggestInput();
@@ -206,10 +323,16 @@ define([
             suggestInput.setSuggestList(function() { return varList; });
             suggestInput.setNormalFilter(false);
             suggestInput.setValue($(divTag + ' #' + obj.name).val());
+            if (obj.placeholder != undefined) {
+                suggestInput.setPlaceholder(obj.placeholder);
+            }
+            if (required === true) {
+                suggestInput.addAttribute('required', true);
+            }
             suggestInput.setSelectEvent(function(selectedValue) {
                 // trigger change
                 $(divTag + ' #' + obj.name).val(selectedValue);
-                $(divTag + ' #' + obj.name).trigger('select_suggestvalue');
+                $(divTag + ' #' + obj.name).trigger('change');
             });
             $(divTag + ' #' + obj.name).replaceWith(function() {
                 return suggestInput.toTagString();
@@ -275,7 +398,7 @@ define([
 
     /**
      * pageId wrap selector
-     * @param {string} pageId vp-option-page의 uuid값
+     * @param {string} pageId vp-option-page uuid
      * @param {string} query 
      */
     var vp_wrapSelector = function(pageId, query) {
@@ -311,7 +434,7 @@ define([
             case 'option_select':
                 var input = $(vp_wrapSelector(pageId, '#'+obj.name)).val();
                 // same as default
-                if (input == obj.default) break;
+                // if (input == obj.default) break;
                 value = input;
                 break;
             case 'var_select':
@@ -320,8 +443,13 @@ define([
             case 'var_multi':
                 value = $(vp_wrapSelector(pageId, '#'+obj.name)).val();
                 break;
+            case 'col_select':
+                value = $(vp_wrapSelector(pageId, '#'+obj.name)).val();
+                break;
             case 'table':
             case 'file':
+            case 'option_suggest':
+            case 'input_number':
             default:
                 var input = $(vp_wrapSelector(pageId, '#'+obj.name)).val();
                 // same as default
@@ -424,26 +552,28 @@ define([
 
     /**
      * Bind columns source function
-     * @param {object} pageThis 
+     * @param {string} selector thisWrapSelector 
      * @param {object} target 
      * @param {array} columnInputIdList 
      * Usage : 
      *  $(document).on('change', this.wrapSelector('#dataframe_tag_id'), function() {
-     *      pdGen.vp_bindColumnSource(that, this, ['column_input_id']);
+     *      pdGen.vp_bindColumnSource(that.wrapSelector(), this, ['column_input_id']);
      *  });
      */
-    var vp_bindColumnSource = function(pageThis, target, columnInputIdList) {
-        var varName = $(target).val();
-
+    var vp_bindColumnSource = function(selector, target, columnInputIdList) {
+        var varName = '';
+        if ($(target).length > 0) {
+            varName = $(target).val();
+        }
         if (varName === '') {
             // reset with no source
             columnInputIdList && columnInputIdList.forEach(columnInputId => {
                 var suggestInputX = new SuggestInput();
                 suggestInputX.setComponentID(columnInputId);
-                suggestInputX.addClass('vp-input');
+                suggestInputX.addClass('vp-input vp-state');
                 suggestInputX.setNormalFilter(false);
-                suggestInputX.setValue($(pageThis.wrapSelector('#' + columnInputId)).val());
-                $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
+                suggestInputX.setValue($(selector + ' #' + columnInputId).val());
+                $(selector + ' #' + columnInputId).replaceWith(function() {
                     return suggestInputX.toTagString();
                 });
             });
@@ -454,22 +584,20 @@ define([
             try {
                 let { result, type, msg } = resultObj;
                 var varResult = JSON.parse(result);
-    
-                if (varResult.length > 0) {
-                    // columns using suggestInput
-                    columnInputIdList && columnInputIdList.forEach(columnInputId => {
-                        var suggestInputX = new SuggestInput();
-                        suggestInputX.setComponentID(columnInputId);
-                        suggestInputX.addClass('vp-input');
-                        suggestInputX.setPlaceholder("column name");
-                        suggestInputX.setSuggestList(function() { return varResult; }); //FIXME:
-                        suggestInputX.setNormalFilter(false);
-                        suggestInputX.setValue($(pageThis.wrapSelector('#' + columnInputId)).val());
-                        $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
-                            return suggestInputX.toTagString();
-                        });
+
+                // columns using suggestInput
+                columnInputIdList && columnInputIdList.forEach(columnInputId => {
+                    var suggestInputX = new SuggestInput();
+                    suggestInputX.setComponentID(columnInputId);
+                    suggestInputX.addClass('vp-input vp-state');
+                    suggestInputX.setPlaceholder("column name");
+                    suggestInputX.setSuggestList(function() { return varResult; }); //FIXME:
+                    suggestInputX.setNormalFilter(false);
+                    suggestInputX.setValue($(selector + ' #' + columnInputId).val());
+                    $(selector + ' #' + columnInputId).replaceWith(function() {
+                        return suggestInputX.toTagString();
                     });
-                }
+                });
             } catch (e) {
                 vpLog.display(VP_LOG_TYPE.ERROR, 'com_generator - bindColumnSource: not supported data type. ', e);
             }
