@@ -18,8 +18,9 @@ define([
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
     'vp_base/js/com/component/PopupComponent',
+    'vp_base/js/com/component/SuggestInput',
     'vp_base/js/com/component/MultiSelector'
-], function(gbHtml, gbCss, com_String, com_util, PopupComponent, MultiSelector) {
+], function(gbHtml, gbCss, com_String, com_util, PopupComponent, SuggestInput, MultiSelector) {
 
     /**
      * Groupby
@@ -29,6 +30,7 @@ define([
             super._init();
             /** Write codes executed before rendering */
             this.config.size = { width: 700, height: 550 };
+            this.config.checkModules = ['pd'];
 
             this.periodList = [
                 { label: 'business day', value: 'B'},
@@ -225,7 +227,7 @@ define([
             
             // reset index checkbox event
             $(document).on('change', this.wrapSelector('#vp_gbResetIndex'), function() {
-                that.state.resetIndex = $(this).val() == 'yes';
+                that.state.resetIndex = $(this).prop('checked');
             });
             
             //====================================================================
@@ -374,18 +376,30 @@ define([
          * @param {string} defaultValue previous value
          */
         templateForVariableList(varList, defaultValue='') {
-            var tag = new com_String();
-            tag.appendFormatLine('<select id="{0}">', 'vp_gbVariable');
-            varList.forEach(vObj => {
-                // varName, varType
-                var label = vObj.varName;
-                tag.appendFormatLine('<option value="{0}" data-type="{1}" {2}>{3}</option>'
-                                    , vObj.varName, vObj.varType
-                                    , defaultValue == vObj.varName?'selected':''
-                                    , label);
-            });
-            tag.appendLine('</select>'); // VP_VS_VARIABLES
-            return tag.toString();
+            // var tag = new com_String();
+            // tag.appendFormatLine('<select id="{0}">', 'vp_gbVariable');
+            // varList.forEach(vObj => {
+            //     // varName, varType
+            //     var label = vObj.varName;
+            //     tag.appendFormatLine('<option value="{0}" data-type="{1}" {2}>{3}</option>'
+            //                         , vObj.varName, vObj.varType
+            //                         , defaultValue == vObj.varName?'selected':''
+            //                         , label);
+            // });
+            // tag.appendLine('</select>'); // VP_VS_VARIABLES
+            // return tag.toString();
+            let mappedList = varList.map(obj => { return { label: obj.varName, value: obj.varName, dtype: obj.varType } });
+
+            var variableInput = new SuggestInput();
+            variableInput.setComponentID('vp_gbVariable');
+            variableInput.addClass('vp-state');
+            variableInput.setPlaceholder('Select variable');
+            variableInput.setSuggestList(function () { return mappedList; });
+            variableInput.setNormalFilter(true);
+            variableInput.addAttribute('required', true);
+            variableInput.setValue(defaultValue);
+
+            return variableInput.toTagString();
         }
 
         /**
@@ -403,6 +417,7 @@ define([
             var defaultMethod = '';
             page.appendFormatLine('<option value="{0}">{1}</option>', '', 'Select method type');
             page.appendFormatLine('<option value="{0}">{1}</option>', 'typing', 'Typing');
+            page.appendLine('<option disabled>-----------------------</option>');
             this.methodList.forEach(method => {
                 if (method.value == '') {
                     return;
@@ -602,7 +617,7 @@ define([
             // Grouper
             if (useGrouper) {
                 byStr = com_util.formatString("pd.Grouper(key={0}, freq='{1}')", byStr, grouperNumber + grouperPeriod);
-            } else if (resetIndex == true) {
+            } else if (resetIndex === true) {
                 // as_index option cannot use with Grouper -> use .reset_index() at the end
                 byStr += ', as_index=False';
             }
@@ -774,7 +789,6 @@ define([
             $(this.wrapSelector('#vp_gbVariable')).val(variable);
             $(this.wrapSelector('#vp_gbBy')).val(groupby.map(col=>col.code).join(','));
             $(this.wrapSelector('#vp_gbBy')).data('list', groupby);
-            $(this.wrapSelector('#vp_gbResetIndex')).val(resetIndex?'yes':'no');
             if (useGrouper) {
                 $(this.wrapSelector('#vp_gbByGrouper')).removeAttr('disabled');
                 $(this.wrapSelector('#vp_gbByGrouper')).prop('checked', useGrouper);
@@ -792,6 +806,7 @@ define([
             }
             $(this.wrapSelector('#vp_gbAllocateTo')).val(allocateTo);
             $(this.wrapSelector('#vp_gbToFrame')).val(toFrame);
+            $(this.wrapSelector('#vp_gbResetIndex')).prop('checked', resetIndex);
 
             if (advPageDom != '') {
                 $(this.wrapSelector('.vp-gb-adv-box')).html(advPageDom);
