@@ -46,6 +46,7 @@ define([
             this.config.dataview = false;
             this.config.runButton = false;
             this.config.size = { width: 500, height: 500 };
+            this.config.checkModules = ['ProfileReport'];
 
             this.selectedReport = '';
         }
@@ -62,6 +63,11 @@ define([
 
             // click menu
             $(this.wrapSelector('.vp-pf-menu-item')).on('click', function() {
+                // check required filled
+                if (that.checkRequiredOption() === false) {
+                    return ;
+                }
+
                 var type = $(this).data('type');
                 var df = $(that.wrapSelector('#vp_pfVariable')).val();
                 var saveas = $(that.wrapSelector('#vp_pfReturn')).val();
@@ -76,8 +82,10 @@ define([
                         code.append(saveas);
                         break;
                 }
-                com_interface.insertCell('code', code.toString(), 'Data Analysis > Profiling');
-                that.loadReportList();
+                that.checkAndRunModules(true).then(function() {
+                    com_interface.insertCell('code', code.toString(), true, 'Data Analysis > Profiling');
+                    that.loadReportList();
+                });
             });
         }
 
@@ -113,7 +121,7 @@ define([
                                     }
                                     var code = new com_String();
                                     code.appendFormat("{0}.to_file('{1}')", varName, path);
-                                    com_interface.insertCell('code', code.toString(), 'Data Analysis > Profiling');
+                                    com_interface.insertCell('code', code.toString(), true, 'Data Analysis > Profiling');
                     
                                     that.selectedReport = '';
                                 });
@@ -124,7 +132,7 @@ define([
                     default:
                         return;
                 }
-                com_interface.insertCell('code', code.toString(), 'Data Analysis > Profiling');
+                com_interface.insertCell('code', code.toString(), true, 'Data Analysis > Profiling');
                 that.loadReportList();
             });
         }
@@ -203,6 +211,7 @@ define([
             variableInput.setPlaceholder('Select variable');
             variableInput.setSuggestList(function () { return mappedList; });
             variableInput.setNormalFilter(true);
+            variableInput.addAttribute('required', true);
             variableInput.setValue(beforeValue);
 
             return variableInput.toTagString();
