@@ -66,20 +66,9 @@ define([
     
             // Searchable variable types
             var types = [
-                // pandas object
-                'DataFrame', 'Series', 'Index', 'Period', 'GroupBy', 'Timestamp'
-                // Index type object
-                , 'RangeIndex', 'CategoricalIndex', 'MultiIndex', 'IntervalIndex', 'DatetimeIndex', 'TimedeltaIndex', 'PeriodIndex', 'Int64Index', 'UInt64Index', 'Float64Index'
-                // GroupBy type object
-                , 'DataFrameGroupBy', 'SeriesGroupBy'
-                // Plot type
-                , 'Figure', 'AxesSubplot'
-                // Numpy
-                , 'ndarray'
-                // Python variable
-                , 'str', 'int', 'float', 'bool', 'dict', 'list', 'tuple'
+                ...vpConfig.getDataTypes(),
                 // ML Data types
-                , ...vpConfig.getMLDataTypes()
+                ...vpConfig.getMLDataTypes()
             ];
     
             var tagTable = this.wrapSelector('#vp_var_variableBox table tbody');
